@@ -178,6 +178,15 @@ class Bridge(object):
         '''
         self._events[name] = []
 
+    def add_callback(self, func, delta):
+        '''Inserts a callback into the event loop, to be run
+        after some time delta.
+
+        @param func Any function of no arguments.
+        @param delta A timedelta or exact datetime object.
+        '''
+        self._connection.loop.add_timeout(delta, func)
+
     def _send(self, args, chain_dict):
         args = list(args)
         args = util.serialize(self, args)
